==> Zephyrus-2.14.10.10607.tar.gz: Zephyrus-2.14.10.10607/Zephyrus/boilerplate/migrations/0002_auto_20170528_2228.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
        ('boilerplate', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='adminplaceholder',
            name='fromUrl',
        ),
        migrations.RemoveField(
            model_name='blockdisplaycontrol',
            name='fromUrl',
        ),
        migrations.AddField(
            model_name='adminplaceholder',
            name='page',
            field=models.ForeignKey(default=None, editable=False, to='cms.Page', null=True),
        ),
        migrations.AddField(
            model_name='adminplaceholder',
            name='useGlobalAdminPlaceholder',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='blockdisplaycontrol',
            name='page',
            field=models.ForeignKey(default=None, editable=False, to='cms.Page', null=True),
        ),
        migrations.AddField(
            model_name='blockdisplaycontrol',
            name='useGlobalBlockDisplayControl',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='adminplaceholder',
            name='name',
            field=models.CharField(max_length=20, null=True, editable=False),
        ),
        migrations.AlterField(
            model_name='blockdisplaycontrol',
            name='name',
            field=models.CharField(max_length=20, null=True, editable=False),
        ),
    ]

==> Zephyrus-5.1.0.13439.tar.gz: Zephyrus-5.1.0.13439/Zephyrus/boilerplate/migrations/0002_auto_20170528_2228.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
        ('boilerplate', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='adminplaceholder',
            name='fromUrl',
        ),
        migrations.RemoveField(
            model_name='blockdisplaycontrol',
            name='fromUrl',
        ),
        migrations.AddField(
            model_name='adminplaceholder',
            name='page',
            field=models.ForeignKey(default=None, editable=False, to='cms.Page', null=True, on_delete=models.CASCADE),
        ),
        migrations.AddField(
            model_name='adminplaceholder',
            name='useGlobalAdminPlaceholder',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='blockdisplaycontrol',
            name='page',
            field=models.ForeignKey(default=None, editable=False, to='cms.Page', null=True, on_delete=models.CASCADE),
        ),
        migrations.AddField(
            model_name='blockdisplaycontrol',
            name='useGlobalBlockDisplayControl',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='adminplaceholder',
            name='name',
            field=models.CharField(max_length=20, null=True, editable=False),
        ),
        migrations.AlterField(
            model_name='blockdisplaycontrol',
            name='name',
            field=models.CharField(max_length=20, null=True, editable=False),
        ),
    ]
